summaryrefslogtreecommitdiff
path: root/src/mongo/s/query/cluster_client_cursor.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/s/query/cluster_client_cursor.h')
-rw-r--r--src/mongo/s/query/cluster_client_cursor.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/mongo/s/query/cluster_client_cursor.h b/src/mongo/s/query/cluster_client_cursor.h
index 008bacd5ef6..1f0d9be54a7 100644
--- a/src/mongo/s/query/cluster_client_cursor.h
+++ b/src/mongo/s/query/cluster_client_cursor.h
@@ -270,11 +270,11 @@ public:
* Returns and releases ownership of the RequestShapifier associated with the request this
* cursor is handling.
*/
- virtual std::unique_ptr<query_stats::RequestShapifier> getRequestShapifier() = 0;
+ virtual std::unique_ptr<telemetry::RequestShapifier> getRequestShapifier() = 0;
protected:
// Metrics that are accumulated over the lifetime of the cursor, incremented with each getMore.
// Useful for diagnostics like queryStats.
OpDebug::AdditiveMetrics _metrics;
private:
@@ -270,11 +270,11 @@ public:
protected:
// Metrics that are accumulated over the lifetime of the cursor, incremented with each getMore.
- // Useful for diagnostics like queryStats.
+ // Useful for diagnostics like telemetry.
OpDebug::AdditiveMetrics _metrics;
private: